@@ -53,9 +53,9 @@ switch($action)
 		param( 'blog_force_skin', 'integer', 0 );
 		$blog_force_skin = 1-$blog_force_skin;
 
-		$blog_tagline = format_to_post( $blog_tagline, 0, 0, $locales[ $blog_locale ][ 'charset' ] );
-		$blog_longdesc = format_to_post( $blog_longdesc, 0, 0, $locales[ $blog_locale ][ 'charset' ] );
-		$blog_notes = format_to_post( $blog_notes, 0, 0, $locales[ $blog_locale ][ 'charset' ] );
+		$blog_tagline = format_to_post( $blog_tagline );
+		$blog_longdesc = format_to_post( $blog_longdesc );
+		$blog_notes = format_to_post( $blog_notes );
 
 		if( empty($blog_stub) )
 		{	// Stub name is empty
@@ -212,9 +212,9 @@ switch($action)
 				param( 'blog_force_skin', 'integer', 0 );
 				$blog_force_skin = 1-$blog_force_skin;
 
-				$blog_tagline = format_to_post( $blog_tagline, 0, 0, $locales[ $blog_locale ][ 'charset' ] );
-				$blog_longdesc = format_to_post( $blog_longdesc, 0, 0, $locales[ $blog_locale ][ 'charset' ] );
-				$blog_notes = format_to_post( $blog_notes, 0, 0, $locales[ $blog_locale ][ 'charset' ] );
+				$blog_tagline = format_to_post( $blog_tagline );
+				$blog_longdesc = format_to_post( $blog_longdesc );
+				$blog_notes = format_to_post( $blog_notes );
 
 				if( empty($blog_stub) )
 				{	// Stub name is empty
@@ -503,6 +503,7 @@ switch($action)
 		// GENERATION!
 		$static_gen_saved_locale = $current_locale;
 		$generating_static = true;
+		$resolve_extra_path = false;
 		flush();
 		ob_start();
 		switch( $edited_Blog->access_type )
