@@ -158,7 +158,7 @@ function format_to_edit( $content, $autobr = false )
 /*
  * format_to_post(-)
  */
-function format_to_post( $content, $autobr = 0, $is_comment = 0, $encoding = 'ISO-8859-1' )
+function format_to_post( $content, $autobr = 0, $is_comment = 0, $encoding = '' )
 {
 	global $use_balanceTags, $use_html_checker, $use_security_checker;
 	global $allowed_tags, $allowed_attribues, $uri_attrs, $allowed_uri_scheme;
@@ -303,28 +303,32 @@ function convert_chars( $content, $flag='html' )
 }
 
 
-/*
- * make_clickable(-)
+/**
+ * Make links clickable in a given text.
+ *
+ * {@internal NOTE: its tested in the misc.funcs.simpletest.php test case }}
+ *
+ * @todo IMHO it would be better to use "\b" (word boundary) to match the beginning of links..
  *
  * original function: phpBB, extended here for AIM & ICQ
  * fplanque restricted :// to http:// and mailto://
  */
-function make_clickable($text)
+function make_clickable( $text, $moredelim = '&amp;' )
 {
-	$ret = ' '. $text;
+	$text = preg_replace(
+		array( '#(^|[\s>])(https?|mailto)://([^<>{}\s]+[^.,<>{}\s])#i',
+			'#(^|[\s>])aim:([^,<\s]+)#i',
+			'#(^|[\s>])icq:(\d+)#i',
+			'#(^|[\s>])www\.([a-z0-9\-]+)\.([a-z0-9\-.\~]+)((?:/[^<\s]*)?[^.,\s])#i',
+			'#(^|[\s>])([a-z0-9\-_.]+?)@([^,<\s]+)#i', ),
+		array( '$1<a href="$2://$3">$2://$3</a>',
+			'$1<a href="aim:goim?screenname=$2$3'.$moredelim.'message='.rawurlencode(T_('Hello')).'">$2$3</a>',
+			'$1<a href="http://wwp.icq.com/scripts/search.dll?to=$2">$2</a>',
+			'$1<a href="http://www.$2.$3$4">www.$2.$3$4</a>',
+			'$1<a href="mailto:$2@$3">$2@$3</a>', ),
+		$text );
 
-	$ret = preg_replace("#([\n ])(http|mailto)://([^, <>{}\n\r]+)#i", "\\1<a href=\"\\2://\\3\">\\2://\\3</a>", $ret);
-
-	$ret = preg_replace("#([\n ])aim:([^,< \n\r]+)#i", "\\1<a href=\"aim:goim?screenname=\\2\\3&message=Hello\">\\2\\3</a>", $ret);
-
-	$ret = preg_replace("#([\n ])icq:([^,< \n\r]+)#i", "\\1<a href=\"http://wwp.icq.com/scripts/search.dll?to=\\2\\3\">\\2\\3</a>", $ret);
-
-	$ret = preg_replace("#([\n ])www\.([a-z0-9\-]+)\.([a-z0-9\-.\~]+)((?:/[^,< \n\r]*)?)#i", "\\1<a href=\"http://www.\\2.\\3\\4\">www.\\2.\\3\\4</a>", $ret);
-
-	$ret = preg_replace("#([\n ])([a-z0-9\-_.]+?)@([^,< \n\r]+)#i", "\\1<a href=\"mailto:\\2@\\3\">\\2@\\3</a>", $ret);
-
-	$ret = substr($ret, 1);
-	return($ret);
+	return $text;
 }
 
 
@@ -768,8 +772,8 @@ function balanceTags($text)
 	}
 
 	# b2 fix for the bug with HTML comments
-	$newtext = str_replace("< !--","<!--",$newtext);
-	$newtext = str_replace("<    !--","< !--",$newtext);
+	$newtext = str_replace( '< !--', '<'.'!--', $newtext ); // the concatenation is needed to work around some strange parse error in PHP 4.3.1
+	$newtext = str_replace( '<    !--', '< !--', $newtext );
 
 	return $newtext;
 }
@@ -1063,8 +1067,13 @@ function validate_url( $url, & $allowed_uri_scheme )
 		return false;
 	}
 
-	if( ! preg_match('/^([a-zA-Z][a-zA-Z0-9+-.]*):[0-9]*/', $url, $matches) )
-	{	// Cannot find URI scheme
+	if( ! preg_match('^														# start
+										([a-z][a-z0-9+.\-]*):[0-9]*		# scheme
+										//														# authority absolute URLs only
+										[a-z][a-z0-9~+.\-_,:;/\\\\]* 	# Don t allow anything too funky like entities
+										([?#][a-z0-9~+.\-_,:;/\\\\%&=#]*)?
+										$ix', $url, $matches) )
+	{	// Cannot vaidate URL structure
 		return T_('Invalid URL');
 	}
 
@@ -1167,7 +1176,7 @@ function debug_info( $force = false )
 		echo 'DB queries: ', $DB->num_queries, '<br />';
 
 		$DB->dump_queries();
-		
+
 		echo '</div>';
 	}
 }
