@@ -996,7 +996,7 @@ function next_posts($max_page = 0, $page='' )
 		$nextpage = intval($paged) + 1;
 		if (!$max_page || $max_page >= $nextpage)
 		{
-			if( !isset($generating_static) )
+			if( !isset($generating_static) || $generating_static == false )
 			{	// We are not generating a static page here:
 				echo regenerate_url( 'paged', 'paged='.$nextpage, $page );
 			}
@@ -1022,7 +1022,7 @@ function previous_posts( $page='' )
 	{
 		$nextpage = intval($paged) - 1;
 		if ($nextpage < 1) $nextpage = 1;
-		if( !isset($generating_static) )
+		if( !isset($generating_static) || $generating_static == false )
 		{	// We are not generating a static page here:
 			echo regenerate_url( 'paged', 'paged='.$nextpage, $page );
 		}
