@@ -85,7 +85,7 @@ if( ($action == 'start') || ($action == 'default') || ($action == 'conf') || ($a
 	{
 		echo '<li>';
 		if( $default_locale == $lkey ) echo '<strong>';
-		echo ' <a href="?action='.$action.'&amp;locale='.$lkey.'">';
+		echo ' <a href="index.php?action='.$action.'&amp;locale='.$lkey.'">';
 		locale_flag( $lkey, 'w16px', 'flag', '', true, "$install_dirout/$img_subdir/flags" );
 		echo T_( $lvalue['name'] );
 		echo '</a></li>';
@@ -231,7 +231,7 @@ switch( $action )
 				fclose($f);
 
 				sprintf( '<p>'.T_('Your configuration file [%s] has been successfully updated.').'</p>', $conf_filepath );
-				
+
 				$baseurl = $conf_baseurl;
 				$admin_email = $conf_admin_email;
 				$config_is_done = 1;
@@ -264,7 +264,7 @@ switch( $action )
 
 			?>
 			<h1><?php echo T_('Base configuration') ?></h1>
-			
+
 			<p><?php echo T_('Your base config file has not been edited yet. You can do this by filling in the form below.') ?></p>
 
 			<p><?php echo T_('This is the minimum info we need to set up b2evolution on this server:') ?></p>
@@ -374,12 +374,12 @@ to
 
 		<p><?php printf( T_('If you don\'t see correct settings here, STOP before going any further, and <a %s>update your base configuration</a>.'), 'href="index.php?action=start&amp;locale='.$default_locale.'"' ) ?></p>
 
-		<?php 
+		<?php
 		if( !isset($conf_db_user) ) $conf_db_user = DB_USER;
 		if( !isset($conf_db_password) ) $conf_db_password = DB_PASSWORD;
 		if( !isset($conf_db_name) ) $conf_db_name = DB_NAME;
 		if( !isset($conf_db_host) ) $conf_db_host = DB_HOST;
-		
+
 		echo '<pre>',
 		T_('mySQL Username').': '.$conf_db_user."\n".
 		T_('mySQL Password').': '.(($conf_db_password != 'demopass' ? T_('(Set, but not shown for security reasons)') : 'demopass') )."\n".
@@ -526,6 +526,10 @@ to
 
 <?php
 	debug_info(); // output debug info if requested
+
+
+	// the following comment gets checked in the automatic install script of demo.b2evolution.net:
 ?>
+<!-- b2evo-install-end -->
 </body>
 </html>
\ No newline at end of file
