@@ -607,7 +607,7 @@ function bloggereditpost($m)
 
 
 $bloggerdeletepost_doc='Deletes a post, blogger-api like';
-$bloggerdeletepost_sig=array(array($xmlrpcString, $xmlrpcString, $xmlrpcString, $xmlrpcString, $xmlrpcString, $xmlrpcBoolean));
+$bloggerdeletepost_sig=array(array($xmlrpcString, $xmlrpcString, $xmlrpcString, $xmlrpcString, $xmlrpcString));
 /**
  * blogger.editPost deletes a given post.
  *
@@ -1517,4 +1517,4 @@ $s=new xmlrpc_server(
 						)
 				);
 
-?>
+?>
\ No newline at end of file
